@@ -1,10 +1,10 @@
 """
-test_xtremes.miscellaneous - Python sublibrary for diverse functions.
+xtremes.miscellaneous - Python sublibrary for diverse functions.
 
 .. code-block:: python
 
     # Import test_xtremes
-    import test_xtremes.miscellaneous as misc
+    import xtremes.miscellaneous as misc
 
     # Call an arbitray function
     misc.sigmoid(1)
@@ -85,14 +85,15 @@ def invsigmoid(y):
     >>> invsigmoid(y)
     array([-1.3652469 ,  0.        ,  1.3652469 ])
     """
-    if y < 0 or y > 1:
+    y = np.array(y)
+    if np.any(y < 0) or np.any(y > 1):
         raise ValueError('Sigmoid only maps to (0, 1)!')
-    elif y < np.exp(-30):
+    elif np.any(y < np.exp(-30)):
         return -30  # exp(-30) = 0
-    elif y > 1 - np.exp(30):
+    elif np.any(y > 1 - np.exp(-30)):
         return 30  # exp(30) = infinity
     else:
-        return inversefunc(sigmoid, y_values=y).item()
+        return inversefunc(sigmoid, y_values=y)
 
 
 def mse(gammas, gamma_true):
@@ -144,7 +145,7 @@ def mse(gammas, gamma_true):
     if len(gammas) > 1:
         MSE = sum((np.array(gammas) - gamma_true)**2)/(len(np.array(gammas))-1)
         variance = sum((np.array(gammas) - np.mean(gammas))**2)/(len(np.array(gammas))-1)
-        bias = MSE - variance
+        bias = np.sqrt(MSE - variance)
         return MSE, variance, bias
     else:
         warnings.warn('No variance can be computed on only 1 element!')
@@ -202,13 +203,12 @@ def GEV_cdf(x, gamma=0, mu=0, sigma=1, theta=1):
 
     """
     x = np.array(x)
-    y = (x-mu)/sigma
+    y = (x - mu) / sigma
     if gamma == 0:
         tau = -np.exp(-y)
     else:
-        tau = (1+gamma*x)**(-1/gamma)
-    out = np.exp(-theta*tau)
-    return out
+        tau = np.where(1 + gamma * y > 0, (1 + gamma * y) ** (-1 / gamma), 0)
+    return np.exp(-theta * tau)
 
 
 
@@ -250,13 +250,13 @@ def GEV_pdf(x, gamma=0, mu=0, sigma=1):
     """
 
     x = np.array(x)
-    y = (x-mu)/sigma #standard
-    if gamma == 0:
-        out = np.exp(-np.exp(-y))*np.exp(-y)/sigma
-    elif 1+gamma*y>0:
-        out = np.exp(-(1+gamma*y)**(-1/gamma))*(1+gamma*y)**(-1/gamma-1)/sigma
+    y = (x - mu) / sigma
+    if gamma < 1e-3:
+        out = np.exp(-np.exp(-y)) * np.exp(-y) / sigma
     else:
-        out = np.zeros_like(x)
+        mask = (1 + gamma * y > 0)
+        out = np.zeros_like(y)
+        out[mask] = np.exp(-(1 + gamma * y[mask]) ** (-1 / gamma)) * (1 + gamma * y[mask]) ** (-1 / gamma - 1) / sigma
     return out
 
 
@@ -299,13 +299,13 @@ def GEV_ll(x, gamma=0, mu=0, sigma=1):
     """
     x = np.array(x)
     sigma = np.abs(sigma)
-    y = (x-mu)/sigma #standard
+    y = (x - mu) / sigma
     if np.abs(gamma) < 0.01:
-        out = -np.log(sigma)-np.exp(-y)-y
-    elif 1+gamma*y>0:
-        out = -np.log(sigma)-(1+gamma*y)**(-1/gamma)+np.log(1+gamma*y)*(-1/gamma-1)
+        out = -np.log(sigma) - np.exp(-y) - y
     else:
-        out = -1000 * np.ones_like(x)
+        mask = (1 + gamma * y > 0)
+        out = np.zeros_like(x)
+        out[mask] = -np.log(sigma) - (1 + gamma * y[mask]) ** (-1 / gamma) + np.log(1 + gamma * y[mask]) * (-1 / gamma - 1)
     return out
 
 # PWM Estimation
@@ -675,6 +675,8 @@ def modelparams2gamma_true(distr, correllation, modelparams):
         return modelparams[0]
     if distr in ['Frechet'] and correllation in ['IID', 'ARMAX', 'AR']: 
         return 1 / modelparams[0]
+    if distr == 'Cauchy' and correllation == 'AR':
+        return 1
     else:
         raise ValueError("Distribution type '{}' or correlation type '{}' is not supported.".format(distr, correllation))
 
